default['slurm']['common']['services'] = {
  server: 'slurmctl',
  compute: 'slurmd',
  accounting: 'slurmdbd',
}

# Use data bags for storing passwords
# Set this to false in order to get the passwords from attributes like:
# node['slurm']['secret'][key][type]
default['slurm']['use_databags'] = true

# Set databag type
# acceptable values 'encrypted', 'standard'. Set this to 'standard' in order to use regular
# databags. This is not recommended for anything other than dev/CI type environments.
default['slurm']['databag_type'] = 'encrypted'

# Default attributes when not using data bags (use_databags = false)
node['slurm']['common']['services'].each_key do |service|
  %w(user service db token).each do |type|
    default['slurm']['secret'][service][type] = "#{service}-#{type}"
  end
end

# platform defaults
default['slurm']['common']['packages'] = value_for_platform(
  [:ubuntu, :debian] => {
    'default': %w(
      python-dev
      python-mysqldb
      python-mysql.connector
    ), # libmariadb-client-lgpl-dev
  }
)

default['slurm']['server']['packages'] = value_for_platform(
  [:ubuntu, :debian] => {
    'default': %w(
      mailutils
      slurm-wlm
      slurm-wlm-basic-plugins
      sview
      nfs-kernel-server
      nfs-common
    ),
  }
)

default['slurm']['compute']['packages'] = value_for_platform(
  [:ubuntu, :debian] => {
    'default': %w(
      slurm-wlm
      slurm-wlm-basic-plugins
      nfs-common
    ),
  }
)

default['slurm']['accounting']['packages'] = value_for_platform(
  [:ubuntu, :debian] => {
    'default': %w(
      slurmdbd
    ),
  }
)

# ========================= Encrypted Databag Setup ===========================
#
# The openstack-common cookbook's default library contains a `secret`
# routine that looks up the value of encrypted databag values. This routine
# uses the secret key file located at the following location to decrypt the
default['slurm']['secret']['key_path'] = Chef::Config[:encrypted_data_bag_secret]

# The name of the encrypted data bag that stores openstack secrets
default['slurm']['secret']['secrets_data_bag'] = 'slurm_secrets'

# The name of the encrypted data bag that stores database passwords, with
# each key in the data bag corresponding to a named Slurm database, like
# "slurmdbd", "slurmctl", "slurmd"
default['slurm']['secret']['db_passwords_data_bag'] = 'slurm_db_passwords'

# ========================= Slurm specific configuration =========================
default['slurm']['common']['conf_dir'] = '/etc/slurm-llnl'

default['slurm']['custom_template_banner'] = "
# This file is automatically generated by Chef
# Any changes will be overwritten
"

default['slurm']['user'] = default['slurm']['group'] = 'slurm'
default['slurm']['uid'] = default['slurm']['gid'] = 999
default['slurm']['comment'] = 'Slurm Workload Manager'

default['slurm']['cluster']['name'] = 'slurm-test'
